@@ -3,6 +3,9 @@
 # $Author: alex $
 # $Revision: 1.34 $
 # $Log: SuperText.pm,v $
+# Revision 1.35  2016/02/01 22:06:42  alex
+# applied patch from RT #24700 by Darren Meyer
+#
 # Revision 1.34  2001/01/17 17:35:51  alex
 # TextANSIColor.pm cool support and bug fixes by Jim Turner
 #
@@ -104,7 +107,7 @@ use vars qw($VERSION @ISA @EXPORT);
 	leftTab copy cut paste inlinePaste undo redo destroy keyPress menuSelect noOP
 );
 
-$VERSION = '0.9.4';
+$VERSION = '0.9.5';
 @ISA = qw(Tk::Derived Tk::Text Exporter);
 
 use base qw(Tk::Text);
@@ -527,7 +530,7 @@ sub insert
 
 	# match coupled chars
 	if((!defined $w->tag('ranges','sel')) && $w->cget('-showmatching') == 1) {
-		if(exists %{$w->{MATCHINGCOUPLES}}->{$str}) {
+		if(exists $w->{MATCHINGCOUPLES}->{$str}) {
 			# calculate visible zone and search only in this one
 			my ($l,$c) = split('\.',$w->index('end'));
 			my ($slimit,$elimit) = $w->yview;
@@ -719,7 +722,7 @@ sub SetCursor
 	$w->SUPER::SetCursor(@_);
 	
 	if((!defined $w->tag('ranges','sel')) && $w->cget('-showmatching') == 1) {
-		if(exists %{$w->{MATCHINGCOUPLES}}->{$str=$w->get('insert','insert + 1c')}) {
+		if(exists $w->{MATCHINGCOUPLES}->{$str=$w->get('insert','insert + 1c')}) {
 			# calculate visible zone and search only in this one
 			my ($l,$c) = split('\.',$w->index('end'));
 			my ($slimit,$elimit) = $w->yview;
@@ -749,7 +752,7 @@ sub Button1
 	$w->SUPER::Button1(@_);
 	
 	if((!defined $w->tag('ranges','sel')) && $w->cget('-showmatching') == 1) {
-		if(exists %{$w->{MATCHINGCOUPLES}}->{$str=$w->get('insert','insert + 1c')}) {
+		if(exists $w->{MATCHINGCOUPLES}->{$str=$w->get('insert','insert + 1c')}) {
 			# calculate visible zone and search only in this one
 			my ($l,$c) = split('\.',$w->index('end'));
 			my ($slimit,$elimit) = $w->yview;
@@ -1897,7 +1900,7 @@ sub flashMatchingChar
 	my $s = $w->index('insert');
 	my $str = $w->get('insert');
 	
-	if(exists %{$w->{MATCHINGCOUPLES}}->{$str}) {
+	if(exists $w->{MATCHINGCOUPLES}->{$str}) {
 		my $i=$w->_FindMatchingChar($str,$s,"1.0","end");
 		if(defined $i) {
 			my $sel = Tk::catch {$w->tag('nextrange','match','1.0','end');};
@@ -2546,9 +2549,13 @@ I<$widget>-E<gt>B<destroy>
 
 I<$widget>-E<gt>B<menuSelect>
 
+=back
+
 =head1 AUTHOR
 
-Alessandro Iob E<lt>I<alexiob@dlevel.com>E<gt>.
+Current maintainer is Alexander Becker, L<c a p f a n -at- g m x %dot% d e>.
+
+Originally written by Alessandro Iob.
 
 =head1 SEE ALSO
 
